package
Version:
v0.10.1
Opens a new window with list of versions in this module.
Published: Dec 21, 2023
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func CopyStruct(src, dst interface{})
将结构体 src 中与 dst 相同的字段值扫描到结构体 dst 中
用法:structkit.CopyStruct(item, &it)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.